@@ -65,8 +65,9 @@ def server_redis(card='eth0', size=None, newer='remi'):
     @todo support change database numbers
     :return:
     """
-    cmd_ulimit()
 
+    utils_remi()
+    cmd_ulimit()
 
     with settings(warn_only=True):
         run('mkdir -p /storage/redis')
@@ -518,6 +519,61 @@ def server_phpd(user='webuser'):
 
 
 
+# def server_smtp():
+#     utils_remi()
+#     cmd_ulimit()
+#
+#     yum_install('sendmail', newer="remi")
+#
+#     run('chkconfig --level 35 sendmail on')
+#
+#     with settings(warn_only=True):
+#         run("sed -i -e \"s/^DAEMON_OPTIONS.*dnl/DAEMON_OPTIONS(\\\`Port=smtp,Name=MTA\')dnl/g\" /etc/mail/sendmail.mc")
+#
+#
+# # yum install postfix dovecot
+# # yum remove sendmail
+#
+#
+#     pass
+
+
+def server_smtp(host,domain,networks):
+    # utils_remi()
+    # cmd_ulimit()
+
+    # yum_install('postfix', newer="remi")
+    # run('yum remove sendmail -y')
+
+
+
+    try:
+        template = pkg_resources.resource_string('fabez', 'tpl/postfix.cf')
+    except:
+        template = open(os.path.join(os.path.dirname(__file__), 'tpl','postfix.cf')).read()
+        pass
+
+    buf = template.replace('{$myhostname}', host) \
+        .replace('{$mydomain}', domain) \
+        .replace('{$mynetworks}', networks) \
+
+
+    # only support python2.x
+    with tempfile.NamedTemporaryFile('w', delete=False) as fh:
+        print>> fh, buf
+
+    put(fh.name, '/etc/postfix/main.cf')
+    os.remove(fh.name)
+
+    run('chkconfig --level 35 postfix on')
+
+    pass
+
+
+
+
+
+
 
 # restart feature
 def restart_web(config=None):
